<?php

	require_once("models/login.php");
	require_once("helpers/input.php");
	require_once("models/mymix_profile.php");
	require_once("models/project.php");
	require_once("models/mymix_discover.php");
	require_once("helpers/ftp.php");
	require_once("helpers/validate.php");
	require_once("models/project_file.php");
	require_once("helpers/filesystem.php");

	Login::require_login();

	// defining some helper functions for this controller
	function extract_tar($source, $dest)
	{
		// Prevent severe damage to system!
		if(empty($dest))
		{
			throw new Exception("Tried to extract tar file with no destination!");
		}
		$command = "rm -rf " . escapeshellarg($dest) . "/*";
		exec($command);
		$command = "tar --strip-components=1 --directory " . escapeshellarg($dest) . " -xzf " . escapeshellarg($source);
		exec($command);
	}

	function push_online_device_configs()
	{
		// Push config out to all online devices
		$known_devices = array();
		exec("ls " . Config::get_item('iex16_devices_dir'), $known_devices);
		$online_devices = MyMix_Discover::get_devices("iex16");
		foreach($online_devices as $iex16_device)
		{
			if(in_array($iex16_device['mac'], $known_devices))
			{
				FTP::push_iex16_profile($iex16_device['ip_address'], $iex16_device['mac']);
			}
		}

		$known_devices = array();
		exec("ls " . Config::get_item('mymix_devices_dir'), $known_devices);
		$online_devices = MyMix_Discover::get_devices("mymix");
		foreach($online_devices as $mymix_device)
		{
			if(in_array($mymix_device['mac'], $known_devices))
			{
				FTP::push_all_mymix_config($mymix_device['ip_address'], $mymix_device['mac']);
			}
		}
	}

	function import_local($import_type, $mac, $item_name)
	{
		switch($import_type)
		{
			case "mymix-profile":
				$profile_name = MyMix_Profile::sanitize_name($item_name);
				$source = Config::get_item('saved_mymix_profiles_dir') . $item_name;
				$dest = Config::get_item('mymix_devices_dir') . $mac . "/profiles/" . $profile_name;
				$redirect_url = "mymix-detail.php?mac=" . urlencode($mac);

				// do the import
				copy($source, $dest);

				// push the device config
				$online_devices = MyMix_Discover::get_devices("mymix");
				foreach($online_devices as $this_device)
				{
					if($this_device['mac'] == $mac)
					{
						FTP::push_mymix_profile($this_device['ip_address'], $mac, $profile_name);
					}
				}
				break;
			case "mymix-pref":
				$source = Config::get_item('saved_mymix_prefs_dir') . $item_name;
				$dest = Config::get_item('mymix_devices_dir') . $mac . "/prefs";
				$redirect_url = "mymix-detail.php?mac=" . urlencode($mac);

				copy($source, $dest);

				// push the device config
				$online_devices = MyMix_Discover::get_devices("mymix");
				foreach($online_devices as $this_device)
				{
					if($this_device['mac'] == $mac)
					{
						FTP::push_mymix_preference($this_device['ip_address'], $mac);
					}
				}
				break;
			case "mymix-lock":
				$source = Config::get_item('saved_mymix_locks_dir') . $item_name;
				$dest = Config::get_item('mymix_devices_dir') . $mac . "/menulock/menulock_mgr";
				$redirect_url = "mymix-detail.php?mac=" . urlencode($mac);

				copy($source, $dest);

				// push the device config
				$online_devices = MyMix_Discover::get_devices("mymix");
				foreach($online_devices as $this_device)
				{
					if($this_device['mac'] == $mac)
					{
						FTP::push_mymix_lock($this_device['ip_address'], $mac);
					}
				}
				break;
			case "iex16-pref":
				$source = Config::get_item('saved_iex16_prefs_dir') . $item_name;
				$dest = Config::get_item('iex16_devices_dir') . $mac . "/prefs";
				$redirect_url = "edit-iex16.php?mac=" . urlencode($mac);

				copy($source, $dest);

				// push the device config
				$online_devices = MyMix_Discover::get_devices("iex16");
				foreach($online_devices as $this_device)
				{
					if($this_device['mac'] == $mac)
					{
						FTP::push_iex16_profile($this_device['ip_address'], $mac);
					}
				}
				break;
			case "mymix-device":
				$source = Config::get_item('saved_mymix_devices_dir') . $item_name;
				$dest = Config::get_item('mymix_devices_dir') . $mac . "/";
				$redirect_url = "mymix-detail.php?mac=" . urlencode($mac);

				extract_tar($source, $dest);

				// push the device config
				$online_devices = MyMix_Discover::get_devices("mymix");
				foreach($online_devices as $this_device)
				{
					if($this_device['mac'] == $mac)
					{
						FTP::push_all_mymix_config($this_device['ip_address'], $mac);
					}
				}
				break;
			case "project":
				$source = Config::get_item('saved_projects_dir') . $item_name . Config::get_item('project_file_ext');
				$dest = Config::get_item('active_project_dir');
				$redirect_url = "save-load-project.php";

                // Unpack the project
				extract_tar($source, $dest);
				
				// Rename the project to match the file it was loaded from
				// See bugzilla #135
				$project = new Project_file(Config::get_item('active_project_dir') . "project.xml");
				$project->set_name($item_name);
				$project->save();

				push_online_device_configs();
				break;
			default:
				throw new Exception("Unknown import type");
				break;
		}
		
		// Properly terminate the FTP session
        FTP::disconnect();
        
        // Ensure changes are written to disk
        Filesystem::sync();

		Url::redirect($redirect_url);
	}

	function import_usb($import_type, $mac, $item_name)
	{
		switch($import_type)
		{
			case "mymix-profile":
				$profile_name = MyMix_Profile::sanitize_name($item_name);
				$source = Config::get_item('external_mymix_profiles_dir') . $item_name;
				$dest = Config::get_item('mymix_devices_dir') . $mac . "/profiles/" . $profile_name;
				$redirect_url = "mymix-detail.php?mac=" . urlencode($mac);

				copy($source, $dest);

				// push the device config
				$online_devices = MyMix_Discover::get_devices("mymix");
				foreach($online_devices as $this_device)
				{
					if($this_device['mac'] == $mac)
					{
						FTP::push_mymix_profile($this_device['ip_address'], $mac, $profile_name);
					}
				}
				break;
			case "mymix-pref":
				$source = Config::get_item('external_mymix_prefs_dir') . $item_name;
				$dest = Config::get_item('mymix_devices_dir') . $mac . "/prefs";
				$redirect_url = "mymix-detail.php?mac=" . urlencode($mac);

				copy($source, $dest);

				// push the device config
				$online_devices = MyMix_Discover::get_devices("mymix");
				foreach($online_devices as $this_device)
				{
					if($this_device['mac'] == $mac)
					{
						FTP::push_mymix_preference($this_device['ip_address'], $mac);
					}
				}
				break;
			case "mymix-lock":
				$source = Config::get_item('external_mymix_locks_dir') . $item_name;
				$dest = Config::get_item('mymix_devices_dir') . $mac . "/menulock/menulock_mgr";
				$redirect_url = "mymix-detail.php?mac=" . urlencode($mac);

				copy($source, $dest);

				// push the device config
				$online_devices = MyMix_Discover::get_devices("mymix");
				foreach($online_devices as $this_device)
				{
					if($this_device['mac'] == $mac)
					{
						FTP::push_mymix_lock($this_device['ip_address'], $mac);
					}
				}
				break;
			case "iex16-pref":
				$source = Config::get_item('external_iex16_prefs_dir') . $item_name;
				$dest = Config::get_item('iex16_devices_dir') . $mac . "/prefs";
				$redirect_url = "edit-iex16.php?mac=" . urlencode($mac);

				copy($source, $dest);

				// push the device config
				$online_devices = MyMix_Discover::get_devices("iex16");
				foreach($online_devices as $this_device)
				{
					if($this_device['mac'] == $mac)
					{
						FTP::push_iex16_profile($this_device['ip_address'], $mac);
					}
				}
				break;
			case "mymix-device":
				$source = Config::get_item('external_mymix_devices_dir') . $item_name;
				$dest = Config::get_item('mymix_devices_dir') . $mac . "/";
				$redirect_url = "mymix-detail.php?mac=" . urlencode($mac);

				extract_tar($source, $dest);

				// push the device config
				$online_devices = MyMix_Discover::get_devices("mymix");
				foreach($online_devices as $this_device)
				{
					if($this_device['mac'] == $mac)
					{
						FTP::push_all_mymix_config($this_device['ip_address'], $mac);
					}
				}
				break;
			case "project":
				$source = Config::get_item('external_projects_dir') . $item_name . Config::get_item('project_file_ext');
				$dest = Config::get_item('active_project_dir');
				$redirect_url = "save-load-project.php";

                // Unpack the project
				extract_tar($source, $dest);
				
				// Rename the project to match the file it was loaded from
				// See bugzilla #135
				$project = new Project_file(Config::get_item('active_project_dir') . "project.xml");
				$project->set_name($item_name);
				$project->save();

				push_online_device_configs();
				break;
			default:
				throw new Exception("Unknown import type");
				break;
		}
		
		// Properly terminate the FTP session
        FTP::disconnect();
        
        // Ensure changes are written to disk
        Filesystem::sync();
	
		Url::redirect($redirect_url);
	}

	function get_uploaded_file_name($control_name)
	{
		// Throw the user a bone, instead of displaying a white screen.
		if($_FILES[$control_name]['error'] == 2)
		{
			die("Uploaded file is too large! Maximum file size is " . ini_get('upload_max_filesize') . " bytes.");
		}

		// Get the uploaded file's name.
		$retval = $_FILES[$control_name]['tmp_name'];

		// prevent some basic hacking attempts
		if(!is_uploaded_file($retval))
		{
			throw new Exception("Tried to import a non-uploaded file! (" . $retval . ")");
		}
		return $retval;
	}

	function import_browser($import_type, $mac)
	{
		$control_name = "upload_file";
		switch($import_type)
		{
			case "mymix-profile":
				$profile_name = MyMix_Profile::sanitize_name($_FILES[$control_name]['name']);
				$dest = Config::get_item('mymix_devices_dir') . $mac . "/profiles/" . $profile_name;
				$redirect_url = "mymix-detail.php?mac=" . urlencode($mac);

				$tmp_filename = get_uploaded_file_name($control_name);
				move_uploaded_file($tmp_filename, $dest);

				// push the device config
				$online_devices = MyMix_Discover::get_devices("mymix");
				foreach($online_devices as $this_device)
				{
					if($this_device['mac'] == $mac)
					{
						FTP::push_mymix_profile($this_device['ip_address'], $mac, $profile_name);
					}
				}
				break;
			case "mymix-pref":
				$dest = Config::get_item('mymix_devices_dir') . $mac . "/prefs";
				$redirect_url = "mymix-detail.php?mac=" . urlencode($mac);

				$tmp_filename = get_uploaded_file_name($control_name);
				move_uploaded_file($tmp_filename, $dest);

				// push the device config
				$online_devices = MyMix_Discover::get_devices("mymix");
				foreach($online_devices as $this_device)
				{
					if($this_device['mac'] == $mac)
					{
						FTP::push_mymix_preference($this_device['ip_address'], $mac);
					}
				}
				break;
			case "mymix-lock":
				$dest = Config::get_item('mymix_devices_dir') . $mac . "/menulock/menulock_mgr";
				$redirect_url = "mymix-detail.php?mac=" . urlencode($mac);

				$tmp_filename = get_uploaded_file_name($control_name);
				move_uploaded_file($tmp_filename, $dest);

				// push the device config
				$online_devices = MyMix_Discover::get_devices("mymix");
				foreach($online_devices as $this_device)
				{
					if($this_device['mac'] == $mac)
					{
						FTP::push_mymix_lock($this_device['ip_address'], $mac);
					}
				}
				break;
			case "iex16-pref":
				$dest = Config::get_item('iex16_devices_dir') . $mac . "/prefs";
				$redirect_url = "edit-iex16.php?mac=" . urlencode($mac);

				$tmp_filename = get_uploaded_file_name($control_name);
				move_uploaded_file($tmp_filename, $dest);

				// push the device config
				$online_devices = MyMix_Discover::get_devices("iex16");
				foreach($online_devices as $this_device)
				{
					if($this_device['mac'] == $mac)
					{
						FTP::push_iex16_profile($this_device['ip_address'], $mac);
					}
				}
				break;
			case "mymix-device":
				$dest = Config::get_item('mymix_devices_dir') . $mac . "/";
				$redirect_url = "mymix-detail.php?mac=" . urlencode($mac);

				$upload_temp = get_uploaded_file_name($control_name);
				$work_name = tempnam("/tmp/", "import");
				move_uploaded_file($upload_temp, $work_name);

				extract_tar($work_name, $dest);

				// push the device config
				$online_devices = MyMix_Discover::get_devices("mymix");
				foreach($online_devices as $this_device)
				{
					if($this_device['mac'] == $mac)
					{
						FTP::push_all_mymix_config($this_device['ip_address'], $mac);
					}
				}

				unlink($work_name);
				break;
			case "project":
				$dest = Config::get_item('active_project_dir');
				$redirect_url = "save-load-project.php";

				$tmp_filename = get_uploaded_file_name($control_name);
				$temp_name = tempnam("/tmp/", "import");
				move_uploaded_file($tmp_filename, $temp_name);

                // Unpack the project
				extract_tar($temp_name, $dest);
				
				// Rename the project to match the file it was loaded from
				// See bugzilla #135
				$project = new Project_file(Config::get_item('active_project_dir') . "project.xml");
				$project_name = $_FILES[$control_name]['name'];
				// Remove the file extension (if present) from uploaded filename
				$extension_length = strlen(Config::get_item('project_file_ext'));
				if(substr($project_name, -$extension_length) == Config::get_item('project_file_ext'))
				{
				    $project_name = substr($project_name, 0, -$extension_length);
				}
				$project->set_name($project_name);
				$project->save();

				push_online_device_configs();

				// Remove the uploaded file.
				unlink($temp_name);
				break;
			default:
				throw new Exception("Unknown import type");
				break;
		}

        // Properly terminate the FTP session
        FTP::disconnect();
        
        // Ensure changes are written to disk
        Filesystem::sync();

		Url::redirect($redirect_url);
	}

	$mac = Input::post('mac');
	$import_type = Input::post('import_type');
	//$import_name = Input::post('import_name');
	$import_from = Input::post('import_from');

	if(!Validate::mac_address($mac) && $import_type != "project")
	{
		die("Invalid MAC address!");
	}
	
	switch($import_from)
	{
		case "local":
			$import_name = Input::post('local_import_name');
			if(empty($import_name))
			{
				die("No import_name specified!");
			}
			import_local($import_type, $mac, $import_name);
			break;
		case "usb":
			$import_name = Input::post('external_import_name');
			if(empty($import_name))
			{
				die("No import_name specified!");
			}
			require_once("helpers/filesystem.php");
			if(!Filesystem::is_usb_mounted())
			{
				die("Error: No USB drive found!");
			}
			import_usb($import_type, $mac, $import_name);
			break;
		case "browser":
			import_browser($import_type, $mac);
			break;
		default:
			die("No import source specified!");
			break;
	}


/* end of import.php */
