<?php

if(!class_exists("Mac_Labels"))
{
	class Mac_Labels {
	
	    // This XML does not go to any Movek devices, so it can contain 
	    // any valid XML. (Note the empty <labels/> node)
	    //
	    // The children of <labels/> should look like this:
	    // <label>
	    //     <id>1</id>
 		//     <name>Label1</name>
 		//     <mac>ff:ff:ff:ff:ff:ff</mac>
 		// </label>
		private static $default_xml = <<< XML
<?xml version="1.0" encoding="iso-8859-1"?>
<labels/>
XML;

		//private static $data_loaded = FALSE;
		
		private static $xml_data;
	    private static $xml_path;
		
		public static function get_label($id)
	    {
		    $retval = "";

		    foreach(self::$xml_data->children() as $this_label)
		    {
			    $this_id = (int)$this_label->id;
			    if($this_id == $id)
			    {
				    $retval = $this_label;
				    break;
			    }
		    }

		    return $retval;
	    }

	    public static function get_label_for_mac($mac)
	    {
		    $retval = "";

		    foreach(self::$xml_data->children() as $this_label)
		    {
			    if($this_label->mac == $mac)
			    {
				    $retval = (string)$this_label->name;
				    break;
			    }
		    }

		    return $retval;
	    }

	    public static function get_mac_for_label($label)
	    {
		    $retval = "";

		    foreach(self::$xml_data->children() as $this_label)
		    {
			    if($this_label->name == $label)
			    {
				    $retval = (string)$this_label->mac;
				    break;
			    }
		    }

		    return $retval;
	    }

	    public static function get_all_labels()
	    {
		    $retval = array();

		    foreach(self::$xml_data->children() as $this_label)
		    {
			    $retval[] = array('id' => (int)$this_label->id, 'name' => (string)$this_label->name, 'mac' => (string)$this_label->mac);
		    }

		    return $retval;
	    }

	    public static function add_label($mac, $name)
	    {
		    self::save_label(0, $mac, $name);
	    }

	    // Passing id of 0 means that a new item will always be added
	    public static function save_label($id, $mac, $name)
	    {
		    $foundit = FALSE;
		    $last_id = 0;
		    foreach(self::$xml_data->children() as $this_label)
		    {
			    if($id > 0 && $this_label->id == $id)
			    {
				    $foundit = TRUE;
				    // Update the node
				    $this_label->mac = $mac;
				    $this_label->name = $name;
			    }
			    $last_id = (int)$this_label->id;
		    }
		    if(!$foundit)
		    {
			    $new_label = self::$xml_data->addChild("label");
			    $new_label->addChild("id", $last_id + 1);
			    $new_label->addChild("name", $name);
			    $new_label->addChild("mac", $mac);
		    }
	    }

	    public static function delete_label($id)
	    {
		    foreach(self::$xml_data->children() as $this_label)
		    {
			    if($this_label->id == $id)
			    {
				    // delete label
				    $oNode = dom_import_simplexml($this_label);
				    $oNode->parentNode->removeChild($oNode);
				    break;
			    }
		    }
	    }
	    
	    public static function load()
	    {
	        require_once("helpers/config.php");
		    //libxml_use_internal_errors(true);
		    $filename = Config::get_item('labels_file');

			// Only try to load the labels file if it exists
			if(file_exists($filename))
			{
				$retval = simplexml_load_file($filename);
			}
			else
			{
				$retval = FALSE;
			}
		    
		    if($retval === FALSE)
		    {
			    /*$errors = libxml_get_errors();
			    $error_message = "";
			    foreach ($errors as $error)
			    {
				    $error_message .= $error->message . " in " . $error->file . " at line " . $error->line . ".\n";
			    }

			    throw new Exception("Failed to open file: " . $error_message);*/
			    $retval = new SimpleXMLElement(self::$default_xml);
		    }

		    self::$xml_data = $retval;
		    self::$xml_path = $filename;
	    }
	    
	    public static function save()
	    {
		    $result = file_put_contents(self::$xml_path, self::$xml_data->saveXML());
		    if($result === FALSE)
		    {
			    $error = error_get_last();
			    throw new Exception("Failed to save file: " . $error['message']);
		    }
	    }
	}
	Mac_Labels::load();
}

/* End of mac_labels.php */
