<?php

// Model to handle interactions with mymix-discover app
class MyMix_Discover {

	// We only need to call mymix-dicover once per page load, since it's very
	// unlikely that the devices on the network will change within that time.
	private static $device_cache = array();
	private static $is_cache_built = FALSE;

	private static $mymix_discover_input = "/tmp/mymix-discover.input";
	private static $mymix_discover_output = "/tmp/mymix-discover.output";


	// Device type is one of mymix, iex16 or all.
	// Returns an array of matching devices found on the network.
	public static function get_devices($device_type)
	{
		$retval = array();

		if(!self::$is_cache_built)
		{

			// Connect to mymix-discover fifos
			$output = fopen(self::$mymix_discover_input, "w");
			$input = fopen(self::$mymix_discover_output, "r");

			fwrite($output, "l\n");
			$output_closed = FALSE;
			$keep_going = true;
			for($this_line = fgets($input); $keep_going; $this_line = fgets($input))
			{
				if(!$output_closed)
				{
					// Data is coming back, so the other end has received our request
					fclose($output);
					$output_closed = TRUE;
				}
				$this_line = trim($this_line);
				if($this_line == "begin device list")
				{
					// nothing to do here yet
				}
				elseif($this_line == "end device list")
				{
					// end of the device list
					$keep_going = FALSE;
				}
				else
				{
					// parse device info
					$fields = explode(";", $this_line);
					if(count($fields) == 6)
					{
						if($fields[3] == "active")
						{
							$retval[] = array(
								'name' => $fields[1], 
								'ip_address' => $fields[4],
								'mac' => $fields[0],
								'type' => $fields[2],
								'status' => "online",
							);
						}
					}
				}
			}
			if(!$output_closed)
			{
				fclose($output);// Make sure the fifo gets closed
			}
			fclose($input);
			self::$device_cache = $retval;
			self::$is_cache_built = TRUE;
		}
		
		if($device_type == "all")
		{
		    return self::$device_cache;
		}
		else
		{
		    $limited = array();
		    foreach(self::$device_cache as $one_device)
		    {
		        if($one_device['type'] == $device_type)
		        {
		            $limited[] = $one_device;
		        }
		    }
		    return $limited;
		}
	}

	// Returns information on just one device, identified by MAC
	public static function get_device_by_mac($device_type, $mac)
	{
		$retval = array();

		$devices = self::get_devices($device_type);

		foreach($devices as $this_device)
		{
			if($this_device['mac'] == $mac)
			{
				$retval = $this_device;
				break;
			}
		}

		return $retval;
	}
	
	// Removes a device from the cache. Use when timeouts occur while connecting to a device.
	public static function remove_device_from_cache($ip_address)
	{
    	$temp_devices = array();
	    foreach(self::$device_cache as &$this_device)
	    {
	        if($this_device['ip_address'] == $ip_address)
	        {
	            $this_device['status'] = "unresponsive";
	        }
	    }
	}
}

/* End of mymix_discover.php */
