<?php
require_once("models/login.php");
require_once("helpers/input.php");
require_once("models/mymix_profile.php");
require_once("helpers/url.php");
require_once("models/mymix_preference.php");
require_once("helpers/ftp.php");
require_once("models/mymix_discover.php");
require_once("helpers/filesystem.php");

$mac = Input::post('mac');
$current_profile_name = Input::post('profile_name');
$new_profile_name = Input::post('new_profile_name');

if(!empty($new_profile_name))
{
    // Profiles with .tmp in the filename are ignored by the myMix.
    if(strpos($new_profile_name, ".tmp") !== FALSE)
    {
        die("Profile names cannot contain '.tmp'");
    }

	// find IP address for this MAC
	$ip_address = "";
	$devices = MyMix_Discover::get_devices("mymix");
	foreach($devices as $this_device)
	{
		if($this_device['mac'] == $mac)
		{
			$ip_address = $this_device['ip_address'];
			break;
		}
	}

	// Rename profile
	MyMix_Profile::rename_profile($mac, $current_profile_name, $new_profile_name);
	// Push new profile name to myMix
	if(!empty($ip_address))
	{
		FTP::push_mymix_profile($ip_address, $mac, $new_profile_name);
		// Inotify on the myMix gets events every 500ms. Give the myMix some
		// time to make sure it "sees" the new profile name.
		// Without this delay, the myMix may try to set an incorrect profile
		// in the prefs.
		sleep(1);
	}

	// Update prefs if this was the current profile
	$pref_path = Config::get_item('mymix_devices_dir') . $mac . "/prefs";
	$pref = new MyMix_Preference($pref_path);

	if($pref->get_current_profile() == $current_profile_name)
	{
		$pref->set_current_profile($new_profile_name);
		$pref->save();
		// Sync prefs
		if(!empty($ip_address))
		{
			FTP::push_mymix_preference($ip_address, $mac);
			
			// Inotify on the myMix gets events every 500ms. Give the myMix some
			// time to make sure it "sees" the prefs change.
			// Without this delay, the myMix will re-save the profile after we
			// delete it below.
			sleep(1);
		}
	}

	// Delete old profile name from myMix
	if(!empty($ip_address))
	{
		FTP::delete_mymix_profile($ip_address, $current_profile_name);
	}

    // Properly terminate the FTP session
    FTP::disconnect();
    
    // Ensure changes are written to disk
    Filesystem::sync();

	Url::redirect("mymix-edit-profile.php?mac=" . urlencode($mac) . "&profile_name=" . urlencode($new_profile_name));
}
else
{
	// show the rename form
	$title = "Confirm delete";
	$ID = "home";

	require("views/header.php");
	require("views/mymix-rename-profile.php");
	require("views/footer.php");
}

/* end of mymix-rename-profile.php */
