#!/bin/bash

# Stop script on error
set -e

# Don't allow unassigned variables
set -u

# This script is used for updating files outside the web application root.
# It is executed after the update is complete. After execution, the entire
# post-update folder is deleted.

# Change to the temp post-update directory
cd /var/www/post-update/

# Added 7/12/2012 for version 1.47g

# Install configuration for usbmount so that www-data can write to USB drives
cp usbmount.conf /etc/usbmount/usbmount.conf
chown root:root /etc/usbmount/usbmount.conf
chmod 644 /etc/usbmount/usbmount.conf
usermod -a -G plugdev www-data

# Added 7/27/2012 for version 1.47h

# Set hostname
cp etc-hostname /etc/hostname
chown root:root /etc/hostname
chmod 644 /etc/hostname

# Added 8/21/2012 for version 1.47h

# Install avahi service to advertise the web interface.
# This allow the plugfinder PC app to discover plug computers.
cp mymix-control.service /etc/avahi/services/

# Added 8/22/2012 for version 1.47h
# See bugzilla 76

# Install network interface configuration.
# This disables DHCP which is enabled on the default plug OS.
cp network-interfaces /etc/network/interfaces
chown root:root /etc/network/interfaces
chmod 644 /etc/network/interfaces

# Added 1/14/2013 for version 1.52
# See bugzilla 162
# Install ifplugd configuration.
# This disables the second DHCP client that wakes up periodically.
cp ifplugd.action /etc/ifplugd/ifplugd.action
chown root:root /etc/ifplugd/ifplugd.action
chmod 755 /etc/ifplugd/ifplugd.action

# Added 3/5/2013 for version 1.52
# See bugzilla 164
# Install mymix-discover to listen for layer 2 discovery messages
# Ignore errors from killall
set +e
killall -9 --quiet mymix-discover
# Reinstate error checking
set -e
cp mymix-discover /sbin/mymix-discover
chown root:root /sbin/mymix-discover
chmod 755 /sbin/mymix-discover
# Install new startup script to include mymix-discover
cp rc.local /etc/rc.local
chown root:root /etc/rc.local
chmod 755 /etc/rc.local
# Update required library
dpkg --auto-deconfigure --force-confold -i libstdc++6_4.4.5-8_armel.deb

# Hook to tell the web interface a reboot is needed.
# This should be second to last.
touch /tmp/reboot-needed

# Sync changes to disk
# Needs to be last, so that any changes made are actually saved to disk.
sync
