<?php
	require_once("models/mymix_discover.php");
	require_once("models/login.php");
	require_once("helpers/config.php");
	require_once("models/mac_labels.php");
	require_once("models/mymix_profile.php");
	require_once("helpers/form.php");
	require_once("helpers/ftp.php");
	require_once("models/mymix_preference.php");
	require_once("helpers/clipboard.php");
	require_once("models/mymix_runtime.php");
	require_once("helpers/filesystem.php");

	Login::require_login();
	
	// Get info on items that have been copied
	$copied_profile = Clipboard::get_mymix_profile();
	$copied_locks = Clipboard::get_mymix_locks();
	$ready_to_paste_profile = !(empty($copied_profile['mac']) || empty($copied_profile['profile_name']));
	$ready_to_paste_locks = !empty($copied_locks['mac']);
	
	$profiles = MyMix_Profile::get_global_profile_list();
	// Add select message to beginning of array (top of list)
	array_unshift($profiles, "Select a profile");
	
	$known_devices = array();
	exec("ls " . Config::get_item('mymix_devices_dir'), $known_devices);
	
	$devices = MyMix_Discover::get_devices("mymix");
	// Try to pull config from all devices. Any devices that fail to communicate
	// will be removed from the online list by the FTP helper class.
	foreach($devices as &$this_device)
	{
        // Pull all config files from this myMix
	    FTP::pull_all_mymix_config($this_device['ip_address'], $this_device['mac']);
	}
	
	// Now get the list off devices that are really online and work with those.
	$devices = MyMix_Discover::get_devices("mymix");
	foreach($devices as &$this_device)
	{
		$prefs = new MyMix_Preference(Config::get_item('mymix_devices_dir') . $this_device['mac'] . "/prefs");
	    $this_device['current_profile'] = $prefs->get_current_profile();

		$remote_device_profile = new MyMix_Profile(Config::get_item('mymix_devices_dir') .
			$this_device['mac'] . "/profiles/" . $prefs->get_current_profile());
	    $this_device['transmit_stereo_mix'] = $remote_device_profile->get_transmit_stereo_mix();
	    
	    $runtime = new MyMix_Runtime(Config::get_item('mymix_devices_dir') . $this_device['mac'] . "/runtime");
	    $this_device['master_mute'] = $runtime->get_master_mute();
	}
	
	// Pull in info for offline devices
	foreach($known_devices as $known_device)
	{
		$found_it = FALSE;
		foreach($devices as $online_device)
		{
			if($known_device == $online_device['mac'])
			{
				$found_it = TRUE;
				break;
			}
		}
		
		// This device is offline, use whatever info was previously cached for it.
		if(!$found_it)
		{
		    $prefs = new MyMix_Preference(Config::get_item('mymix_devices_dir') . $known_device . "/prefs");

    		$remote_device_profile = new MyMix_Profile(Config::get_item('mymix_devices_dir') .
	    		$known_device . "/profiles/" . $prefs->get_current_profile());

			$devices[] = array(
				'mac' => $known_device,
				'name' => "",
				'status' => "offline",
                'current_profile' => $prefs->get_current_profile(),
                'transmit_stereo_mix' => $remote_device_profile->get_transmit_stereo_mix(),
                'master_mute' => "0"
			);
		}
	}
	
	// Add device labels to all devices
	// Add names to all devices from locally stored preferences. The prefs
	// tend to be more up-to-date than discovery info.
	foreach($devices as &$this_device)
	{
        $this_device['label'] = Mac_Labels::get_label_for_mac($this_device['mac']);
        $prefs = new MyMix_Preference(Config::get_item('mymix_devices_dir') . $this_device['mac'] . "/prefs");
		$this_device['name'] = $prefs->get_unit_name();
	}
	
	// Properly terminate the FTP session
    FTP::disconnect();
    
    // Ensure changes are written to disk
    Filesystem::sync();

	// Data for header
	$title = "Select MyMix device";
    $ID = "mymix";

	require("views/header.php");
	require("views/mymix-table.php");
	require("views/footer.php");

/* End of view-mymix.php */
